pub trait DirEntryExt {
// Required method
fn full_metadata(&self) -> Result<Metadata>;
}Expand description
Extension trait for DirEntry.
Required Methods
Sourcefn full_metadata(&self) -> Result<Metadata>
fn full_metadata(&self) -> Result<Metadata>
Return the full metadata, which on Windows includes the optional values.
If the full metadata cannot be computed, this fails rather than
falling back to partial metadata, even when that might not fail.
If partial metadata is desired, std::fs::DirEntry::metadata can
be used.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl DirEntryExt for DirEntry
Available on non-Windows only.
impl DirEntryExt for DirEntry
Available on non-Windows only.
fn full_metadata(&self) -> Result<Metadata>
Sourceimpl DirEntryExt for DirEntry
Available on crate feature std and non-Windows only.
impl DirEntryExt for DirEntry
Available on crate feature
std and non-Windows only.